BoundErrorKind

Enum BoundErrorKind 

pub enum BoundErrorKind {
    LessThanZero,
    GreaterThanOne,
    Neither,
}
Describes how a value falls outside the closed unit interval [0, 1]

Examples

use unit_interval::{UnitInterval, BoundErrorKind};

let result = UnitInterval::new_checked(-0.5);
assert_eq!(result.unwrap_err().kind(), BoundErrorKind::LessThanZero);

let result = UnitInterval::new_checked(1.5);
assert_eq!(result.unwrap_err().kind(), BoundErrorKind::GreaterThanOne);

let result = UnitInterval::new_checked(f32::NAN);
assert_eq!(result.unwrap_err().kind(), BoundErrorKind::Neither);

Variants



LessThanZero

The value is less than both zero and one

When T::zero() <= val is false but val <= T::one() is true.



GreaterThanOne

The value is greater than both zero and one

When T::zero() <= val is true but val <= T::one() is false.



Neither

The value is neither greater than or equal to zero nor less than or equal to one

When both T::zero() <= val and val <= T::one() are false.

This can mean 2 things:

  1. The value is NaN-like
  2. The comparison operations (PartialOrd) or Zero or One are incorrectly implemented for the type of the value